@@ -1,5 +1,7 @@
 from typing import List, Union
+from statsmodels.tsa.seasonal import seasonal_decompose
 
+import sys, os, io
 from pandas import DataFrame
 import pandas as pd
 
@@ -11,13 +13,10 @@ from tabulate import tabulate
 
 from tscausalinference.synth_regression import synth_analysis
 from tscausalinference.bootstrap import bootstrap_simulate, bootstrap_p_value
-from tscausalinference.load_synth_data import create_synth_dataframe
 
 sns.set_theme()
 sns.set_context("paper")
 
-pd.options.mode.chained_assignment = None 
-
 class tscausalinference:
     """
    Time series causal inference using structural causal models (SCM) and a difference-in-differences (DiD) approach.
@@ -49,12 +48,6 @@ class tscausalinference:
         Plots the time series data before and after the intervention with confidence intervals.
     plot_simulations(simulation_number: int = 10)
         Plots a specified number of bootstrap simulations.
-    summary()
-        Plots an overview about the results.
-    summary_intervention()
-        Plots an overview of the results during intervention period.
-    seasonal_decompose()
-        Plots the seasonal decomposition of the time series.
     """
 
     def __init__(self,
@@ -66,9 +59,10 @@ class tscausalinference:
         back_window: int = 25,
         seasonality: bool = True,
         n_samples: int = 1500,
-        cross_validation_steps: int = 5,
-        seasonality_mode: str = 'additive'
+        cross_validation_steps: int = 5
         ):
+        """
+        """
 
         self.data = data
         self.intervention = intervention
@@ -79,16 +73,13 @@ class tscausalinference:
         self.regressors = regressors
         self.n_samples = n_samples
         self.cross_validation_steps = cross_validation_steps
-        self.seasonality_mode = seasonality_mode
 
         self.data, self.pre_int_metrics, self.int_metrics = synth_analysis(
             df = data, 
             regressors = regressors, 
             intervention = intervention, 
             seasonality = seasonality,
-            cross_validation_steps = cross_validation_steps,
-            alpha = alpha,
-            model_mode = seasonality_mode
+            cross_validation_steps = cross_validation_steps
             )
         self.string_filter = "ds >= '{}' & ds <= '{}'".format(intervention[0],intervention[1])
         
@@ -116,7 +107,7 @@ class tscausalinference:
         --------
             No returns are defined, as the method simply generates a plot.
         """
-        data = self.data.copy()
+        data = self.data
         fig, axes = plt.subplots(nrows=2, ncols=1, figsize=(15, 10))
 
         lineplot = sns.lineplot(x = 'ds', y = 'yhat', color = 'r', alpha=0.5, linestyle='--', ci=95,
@@ -173,7 +164,7 @@ class tscausalinference:
         -------
             ValueError: if simulation_number is greater than the number of simulations generated.
         """
-        data = self.data.copy()
+        data = self.data
 
         fig, axes = plt.subplots(nrows=1, ncols=2, figsize=(18, 5))
         for i in range(simulation_number):#range(len(samples[0])):
@@ -181,7 +172,7 @@ class tscausalinference:
                         linewidth=0.5, alpha=0.45,
                         color = 'orange', legend = False, ax=axes[0])
 
-        sns.lineplot(x = 'ds', y = 'y', color = 'b',
+        sns.lineplot(x = 'ds', y = 'yhat', color = 'b',
                     err_kws={'linestyle': '--', 'hatch': '///', 'fc': 'none'}, ax=axes[0],
                     data = data[(data.ds <= pd.to_datetime(self.intervention[0]))],
                     linewidth=1, label='Training')
@@ -238,11 +229,17 @@ class tscausalinference:
         --------
             No returns are defined, as the method simply generates a overview.
         """
-        data = self.data.copy()
+        data = self.data
         
         data['ds'] = pd.to_datetime(data['ds'])
+        x_decomp = data[(data.ds <= pd.to_datetime(self.intervention[0]))][['ds', 'y']].set_index('ds')
 
-        std_res = self.pre_int_metrics[3][1]
+        decomposition_obj = seasonal_decompose(
+                    x = x_decomp, 
+                    model = 'additive'
+                    )
+        
+        std_res = decomposition_obj.resid.describe()['std']
 
         if std_res < 0.2:
             mde = 15
@@ -268,8 +265,8 @@ class tscausalinference:
     The 95% confidence interval of this counterfactual prediction is {} to {}.
 
     The usual error of your model is {}%, while the difference during the intervention period is {}%. 
-    During the intervention, the error increase {}% ({} percentage points), suggesting some factor is 
-    impacting the quality of the model, and the differences are significant.
+    During the intervention, the error was {}%, suggesting some factor is impacting the quality of the model,
+    and that the differences significant.
 
     The probability of obtaining this effect by chance is very small 
     (after {} simulations, bootstrap probability p = {}). 
@@ -289,7 +286,7 @@ class tscausalinference:
     The 95% confidence interval of this counterfactual prediction is {} to {}.
 
     The usual error of your model is {}%, while the difference during the intervention period is {}%. 
-    During the intervention, the error increase {}% ({} percentage points), suggesting that the model can explain well what should happen,
+    During the intervention, the error was {}%, suggesting that the model can explain well what should happen,
     and that the differences are not significant.
 
     The probability of obtaining this effect by chance is not small 
@@ -299,7 +296,7 @@ class tscausalinference:
 
         print(
             summary.format(
-                round(std_res,5),
+                round(std_res,2),
                 noise,
                 mde,
                 round(data[(data.ds >= pd.to_datetime(self.intervention[0])) & (data.ds <= pd.to_datetime(self.intervention[1]))].y.mean(),2),
@@ -309,9 +306,8 @@ class tscausalinference:
                 round(self.pre_int_metrics[2][1],2),
                 round(self.int_metrics[3][1],2),
                 round(self.int_metrics[3][1]/self.pre_int_metrics[2][1],2),
-                round(self.int_metrics[3][1] - self.pre_int_metrics[2][1],2),
                 self.n_samples,
-                round(self.stadisticts[0],5)
+                self.stadisticts[0]
             )
         )
     
@@ -332,11 +328,11 @@ class tscausalinference:
         data = self.data
 
         strings_info = """
-+-----------------------+-------------+
-        intervention metrics
-+-----------------------+-------------+
++-----------------------+-----------+
+      Pre intervention metrics
++-----------------------+-----------+
 {}
-+-----------------------+-------------+
++-----------------------+-----------+
       {}
         """
 
@@ -350,68 +346,3 @@ class tscausalinference:
                     round(data[(data.ds >= self.intervention[0]) & (data.ds <= self.intervention[1])].yhat_upper.sum()),2)
             ).strip()
         )
-
-    def seasonal_decompose(self):
-        data = self.data.copy()
-        data['ds'] = pd.to_datetime(data['ds'])
-        data.set_index('ds', inplace = True)
-
-        data = data[(data.index < self.intervention[0])].copy()
-
-        cols = list(set(data.columns.to_list()) - set(['point_effects', 'yhat', 'yhat_lower', 'yhat_upper', 'cummulitive_y', 'cummulitive_yhat', 'cummulitive_effect', 'cummulitive_yhat_lower', 'cummulitive_yhat_upper']))
-
-        fig, axes = plt.subplots(nrows=len(cols), ncols=1, figsize=(18, 12))
-
-        for number, name in enumerate(cols):
-            sns.lineplot(x = data.index, y = data[name], color = 'b', ax=axes[number], linewidth=1, label = name)
-        
-        # Show the plot
-        sns.despine()
-
-class synth_dataframe:
-    """
-    Creates a synthetic dataframe with time series components.
-
-    Args:
-    - n (int): Number of periods to generate.
-    - trend (float): Slope of the trend component.
-    - seasonality (int): Period of the seasonality component.
-    - simulated_effect (float): Multiplicative effect of the treatment.
-    - eff_n (int): Number of periods the treatment lasts.
-    - noise_power (float): Scale of the noise component.
-    - regressor (int): Number of regressors to include in the dataframe.
-
-    Methods:
-    - DataFrame: Returns a pandas dataframe with columns 'ds', 'y' and the regressors created.
-
-    Example:
-    >>> synth = synth_dataframe(n=365, trend=0.1, seasonality=7, simulated_effect=1.2, eff_n=30, noise_power=0.1, regressor=3)
-    >>> df = synth.DataFrame()
-    """
-
-    def __init__(self,
-                n: int = 365, 
-                trend: float = 0.1, 
-                seasonality: int = 7, 
-                simulated_effect: float = 0.15, 
-                eff_n: int = 15, 
-                noise_power: float = 0.15, 
-                regressors: int = 2):
-        self.n = n
-        self.seasonality = seasonality
-        self.trend = trend
-        self.simulated_effect = simulated_effect
-        self.eff_n = eff_n
-        self.noise_power = noise_power
-        self.regressors = regressors
-
-        self.df = create_synth_dataframe(n = self.n, 
-                           trend = self.trend, 
-                           seasonality = self.seasonality, 
-                           simulated_effect = self.simulated_effect, 
-                           eff_n = self.eff_n, 
-                           noise_power = self.noise_power, 
-                           regressor = self.regressors)
-    
-    def DataFrame(self):
-        return self.df
\ No newline at end of file
